[![Blender](docs/blender-version.svg)](https://www.blender.org/download/releases/4-4/) ![Python](docs/python.svg) [![Test Status](https://github.com/varkenvarken/blempy/actions/workflows/test_all.yml/badge.svg)](https://github.com/varkenvarken/blempy/actions/workflows/test_all.yml) ![Coverage](docs/coverage.svg) ![PyPI - Version](https://img.shields.io/pypi/v/blempy)

# blempy — Blender ↔ NumPy helpers

`blempy` provides small, safe utilities to efficiently transfer Blender property-collection attributes (e.g. vertex coordinates) to/from NumPy arrays and perform vectorized operations with minimal Python overhead.

More information on [the website](https://varkenvarken.github.io/blempy/) accompanying this repo.

## contributing

I am happy to review pull requests with improvements or even complete new add-ons. Just make sure:
- The code is yours,
- is licensed under GPL v3 or later,
- runs on the current Blender version (see label at top of this file),
- and comes with extensive test coverage
